@@ -13,13 +13,12 @@ import logging
 from typing import NoReturn
 
 import pygame
-from pygame.constants import (KEYDOWN, K_SPACE, K_RETURN, K_UP, K_DOWN, K_LEFT,
-                              K_RIGHT, KEYUP, K_ESCAPE, K_EQUALS, K_MINUS)
 
-from pi_touch_gui.page import Page
 from pi_touch_gui._utilities import backlog_error
 from pi_touch_gui.multitouch.raspberrypi_ts import Touchscreen
 
+# from pi_touch_gui.page import Page
+
 LOG = logging.getLogger(__name__)
 
 
@@ -99,7 +98,7 @@ class GUI(object):
         with open('/sys/class/backlight/rpi_backlight/bl_power', 'w') as f:
             f.write(blank_str)
 
-    def run(self, page, callback=None, cb_rate=None) -> NoReturn:
+    def run(self, start_page, callback=None, cb_rate=None) -> NoReturn:
         """ Run the GUI, staring with the initial Page.
 
         Does not return, but does an exit() when done. Wrapping
@@ -107,7 +106,7 @@ class GUI(object):
 
         Parameters
         ----------
-        page : Page
+        start_page : Page
             The starting page to display
         callback : Callable[GUI, Page]
             An optional method to inject into the GUI main loop, for managing
@@ -120,8 +119,8 @@ class GUI(object):
             callback (it helps if it's some multiple of 1/60, as the primary
             loop rate is 60 frames a second).
         """
-        self._current_page = page
-        self._first_page = page
+        self._current_page = start_page
+        self._first_page = start_page
         self._running = True
 
         self._touchscreen.run()
@@ -139,10 +138,7 @@ class GUI(object):
 
             new_page = self._current_page.touch_handler(e, t)
             if new_page is not None:
-                # if isinstance(new_page, Page):
                 self._current_page = new_page
-                # else:
-                #     LOG.error(f"Unsupported touch result {type(new_page)!r}")
 
         # All touch types go through the `Page.touch_handler()`
         for touch in self._touchscreen.touches:
@@ -173,50 +169,6 @@ class GUI(object):
                 self._current_page.render(self._touchscreen.surface)
                 pygame.display.flip()
 
-                # Check for keyboard events, to support VNC interactions
-                events = pygame.event.get()
-                new_page = None
-                if len(events) > 0:
-                    for event in events:
-                        if event.type == KEYDOWN:
-                            page = self._current_page
-                            if event.key in [K_SPACE, K_RETURN]:
-                                if page.is_focused():
-                                    page.press_widget()
-
-                            if event.key == K_UP:
-                                page.shift_widget_focus(Page.GO_UP)
-                            elif event.key == K_DOWN:
-                                page.shift_widget_focus(Page.GO_DOWN)
-                            elif event.key == K_LEFT:
-                                page.shift_widget_focus(Page.GO_LEFT)
-                            elif event.key == K_RIGHT:
-                                page.shift_widget_focus(Page.GO_RIGHT)
-                        if event.type == KEYUP:
-                            page = self._current_page
-                            if event.key in [K_SPACE, K_RETURN]:
-                                if page.is_focused():
-                                    new_page = page.release_widget()
-                                    page.focus_widget(False)
-                                else:
-                                    page.focus_widget(True)
-
-                            elif event.key == K_ESCAPE:
-                                page.focus_widget(False)
-
-                if pygame.key.get_pressed()[K_EQUALS]:
-                    page.adjust_widget(1)
-                elif pygame.key.get_pressed()[K_MINUS]:
-                    page.adjust_widget(-1)
-
-                # The keyboard interactions may have set a new page
-                if new_page is not None:
-                    if isinstance(new_page, Page):
-                        self._current_page = new_page
-                    else:
-                        LOG.error(f"Unsupported page result "
-                                  f"{type(new_page)!r}")
-
                 # Lock it into the framerate
                 fps_clock.tick(self.FPS)
 
