@@ -54,6 +54,15 @@ class Touch(object):
         self._on_move = None
         self._on_press = None
         self._on_release = None
+        self._page = None
+
+    @property
+    def page(self):
+        return self._page
+
+    @page.setter
+    def page(self, page):
+        self._page = page
 
     @property
     def position(self):
