@@ -1,4 +1,4 @@
-from pathlib import Path
+from pi_touch_gui import Page
 
 
 def get_pages():
@@ -6,7 +6,4 @@ def get_pages():
     from test_pages.poweroff_page import poweroff_page
     from test_pages.sampler_page import sampler_page
 
-    _background = str(Path(Path(__file__).parent, "assets/lcars_screen.png"))
-
-    return [entry_page(), sampler_page(_background), poweroff_page()]
-
+    return [entry_page(), sampler_page(Page.LCARS), poweroff_page()]
